"""Provides deprecation warnings and utilities for triggering warnings.

By default, this sets all `DrakeDeprecationWarnings` to be shown `"once"`,
which overrides any `-W` command-line arguments. To change this behavior, you
can do something like:

>>> import warnings
>>> from pydrake.common.deprecation import DrakeDeprecationWarning
>>> warnings.simplefilter("always", DrakeDeprecationWarning)

If you would like to disable all Drake-related warnings, you may use the
`"ignore"` action for `warnings.simplefilter`.

The severity of deprecation warnings can also be controlled via the
``DRAKE_DEPRECATION_RUNTIME_SEVERITY`` environment variable, which is read
when this module is imported (i.e., during ``import pydrake``):

- ``DRAKE_DEPRECATION_RUNTIME_SEVERITY=error`` — treat deprecation warnings as
  errors (raises ``DrakeDeprecationWarning`` instead of logging a warning).
- ``DRAKE_DEPRECATION_RUNTIME_SEVERITY=ignore`` — silently discard deprecation
  warnings.
- unset — show each deprecation warning once.
"""

import os
import re
import sys
from types import ModuleType
import warnings

# TODO(eric.cousineau): Make autocomplete ignore `ModuleShim` attributes
# (e.g. `install`).
# TODO(eric.cousineau): Remove ModuleShim once Drake requires Python >= 3.7
# (for PEP 562).


class ModuleShim:
    """Provides a shim for automatically resolving extra variables.

    This can be used to deprecate import alias in modules to simplify
    dependencies.

    See Also:
        https://stackoverflow.com/a/7668273/7829525

    Note:
        This is not necessary in Python >= 3.7 due to PEP 562.
    Warning:
        This will not work if called on a cc module during import (e.g. using
        ExecuteExtraPythonCode). Instead, you should rename the module from
        `{name}` to `_{name}`, and import the symbols into the new module using
        _import_cc_module_vars.
    """

    def __init__(self, orig_module, handler):
        assert hasattr(orig_module, "__all__"), (
            "Please define `__all__` for this module."
        )
        assert isinstance(orig_module, ModuleType), (
            f"{orig_module} must be a module"
        )
        # https://stackoverflow.com/a/16237698/7829525
        object.__setattr__(self, "_orig_module", orig_module)
        object.__setattr__(self, "_handler", handler)
        object.__setattr__(self, "__doc__", orig_module.__doc__)

    def __getattr__(self, name):
        # Use the original module if possible.
        m = self._orig_module
        if hasattr(m, name):
            return getattr(m, name)
        else:
            # Otherwise, use the handler, and store the result.
            try:
                value = self._handler(name)
            except AttributeError as e:
                if str(e):
                    raise e
                else:
                    raise AttributeError(
                        f"'module' object has no attribute '{name}'"
                    )
            setattr(m, name, value)
            return value

    def __setattr__(self, name, value):
        # Redirect writes to the original module.
        setattr(self._orig_module, name, value)

    def __delattr__(self, name):
        # Redirect deletions to the original module.
        delattr(self._orig_module, name)

    def __repr__(self):
        return repr(self._orig_module)

    def __dir__(self):
        # Implemented to provide a useful subset of completions to
        # `rlcompleter`.
        return self._orig_module.__all__

    @classmethod
    def _install(cls, name, handler, *, auto_all=False):
        """Hook into module's attribute accessors and mutators.

        Args:
            name: Module name. Generally should be __name__.
            handler: Function of the form `handler(var)`, where `var` is the
                variable name.
            auto_all: If True, this will override `__all__` with a listing of
                all non-private variables in the module.

        Note:
            This is private such that `install` does not pollute completion
            candidations provided by `rlcompleter` when it iterates through
            `__bases__`.
        """
        old_module = sys.modules[name]
        if auto_all:
            old_module.__all__ = [
                name for name in old_module.__dict__ if not name.startswith("_")
            ]
        new_module = cls(old_module, handler)
        sys.modules[name] = new_module


class DrakeDeprecationWarning(DeprecationWarning):
    """Extends `DeprecationWarning` to permit Drake-specific warnings to
    be filtered by default, without having side effects on other libraries."""

    pass


def _format_deprecation_message(message, *, date=None):
    assert isinstance(message, str), repr(message)
    if date is not None:
        assert isinstance(date, str), repr(date)
        assert date != "None"
        assert _date_pattern.fullmatch(date) is not None, (
            f"Date does not match YYYY-MM-DD pattern: {repr(date)}"
        )
        # N.B. This follows the formatting in `mkdoc.py`.
        message = (
            f"{message} The deprecated code will be removed from Drake on or "
            f"after {date}."
        )
    assert _date_pattern.search(message) is not None, (
        f"Deprecation messages should have a removal date in the form of "
        f"YYYY-MM-DD. Consider passing in the kwarg `date='YYYY-MM-DD' to "
        f"have a preformatted message.\n"
        f"Original message:\n"
        f"{message}"
    )
    return message


def _warn_deprecated(message, *, date=None, stacklevel=2):
    # Logs a deprecation warning message.  Also used by `deprecation_pybind.h`
    # in addition to this file.
    warnings.warn(
        _format_deprecation_message(message, date=date),
        category=DrakeDeprecationWarning,
        stacklevel=stacklevel,
    )


class _DeprecatedDescriptor:
    """Wraps a descriptor to warn that it is deprecated any time it is
    accessed.
    """

    def __init__(self, original, message, *, date=None):
        assert hasattr(original, "__get__"), (
            f"`original` must be a descriptor: {original}"
        )
        self._original = original
        self.__doc__ = self._original.__doc__
        self._message = message
        self._date = date

    def _warn(self):
        _warn_deprecated(self._message, date=self._date, stacklevel=4)

    def __get__(self, obj, objtype):
        self._warn()
        return self._original.__get__(obj, objtype)

    def __set__(self, obj, value):
        self._warn()
        self._original.__set__(obj, value)

    def __delete__(self, obj):
        self._warn()
        self._original.__delete__(obj)


def deprecated(message, *, date=None):
    """Decorator that deprecates a member of a class based on access.

    Args:
        message: Warning message when member is accessed.
        date: (Optional) String of the form "YYYY-MM-DD".
            If supplied, will reformat the message to add the date as is done
            with DRAKE_DEPRECATED and its processing in mkdoc.py. This must be
            present if ``message`` does not contain the date itself.

    Note:
        This differs from other implementations in that it warns on access,
        not when the method is called. For other methods, see the examples in
        https://stackoverflow.com/a/40301488/7829525.

    Use `ModuleShim` for deprecating variables in a module.
    """
    # TODO(eric.cousineau): If possible, distinguish between descriptors and
    # free functions. See PR #15877 for attempt.

    def wrapped(original):
        return _DeprecatedDescriptor(original, message, date=date)

    return wrapped


def install_numpy_warning_filters(force=False):
    """Install warnings filters specific to NumPy."""
    global _installed_numpy_warning_filters
    if _installed_numpy_warning_filters and not force:
        return
    _installed_numpy_warning_filters = True
    # Warnings specific to comparison with `dtype=object` should be raised to
    # errors (#8315, #8491). Without them, NumPy will swallow the errors and
    # make a DeprecationWarning, while returning effectively garbage values
    # (e.g. comparison based on object ID): either a scalar bool or an array of
    # bools (based on what objects are present and the NumPy version).
    # N.B. Using a `module=` regex filter does not work, as the warning is
    # raised from C code, and thus inherits the calling module, which may not
    # be "numpy\..*" (numpy/numpy#10861).
    warnings.filterwarnings(
        "error", category=DeprecationWarning, message="numpy equal will not"
    )
    warnings.filterwarnings(
        "error",
        category=DeprecationWarning,
        message="elementwise == comparison failed",
    )
    warnings.filterwarnings(
        "error",
        category=DeprecationWarning,
        message="elementwise != comparison failed",
    )
    # Error changed in 1.16.0
    warnings.filterwarnings(
        "error",
        category=DeprecationWarning,
        message="elementwise comparison failed",
    )

    # TODO(#17898): This is not a deprecation per se, nor is it promoting the
    # deprecation to warning. However, this warning currently does not incur
    # a functional penalty, so we suppress the warning to minimize
    # distractions. Root-cause investigation pending.
    warnings.filterwarnings(
        "ignore",
        category=RuntimeWarning,
        message="invalid value encountered in",
    )


def deprecated_callable(message, *, date=None):
    """
    Deprecates a callable (a free function or a type/class object) by
    wrapping its invocation to emit a deprecation.

    When possible, use ModuleShim to ensure that a deprecation warning is
    emitted at *import time*, as it can easily be used with pure Python
    modules.

    However, if you are dealing with a C++ module (and are writing code inside
    of `_{module}_extra.py`), you should use this approach.

    Example:
        ::

            # As decorator
            @deprecated_callable("Please use `func_y` instead", date="2038-01-19")  # noqa
            def func_x():
                ...

            # As alias
            deprecated_alias = deprecated_callable(
                "Please use `real_callable` instead", date="2038-01-19"
            )(real_callable)
    """

    def decorator(original):
        def wrapped(*args, **kwargs):
            _warn_deprecated(message, date=date, stacklevel=3)
            return original(*args, **kwargs)

        wrapped.__name__ = original.__name__
        wrapped.__qualname__ = original.__name__
        warning = _format_deprecation_message(message, date=date)
        wrapped.__doc__ = f"Warning:\n\n    {warning}"

        return wrapped

    return decorator


def _forward_callables_as_deprecated(var_dict, m_new, date):
    # Forwards public symbols from `m_new` to `var_dict`, while wrapping
    # each symbol to emit a deprecation warning when it is called.
    # Warning: This assumes all relevant symbols are callable!
    all_public = [x for x in m_new.__dict__ if not x.startswith("_")]
    symbols = getattr(m_new, "__all__", all_public)
    for symbol in symbols:
        new = getattr(m_new, symbol)
        assert hasattr(new, "__call__")
        old_name = var_dict["__name__"]
        message = (
            f"Please use ``{m_new.__name__}.{symbol}`` instead of "
            f"``{old_name}.{symbol}``."
        )
        old = deprecated_callable(message, date=date)(new)
        old.__module__ = old_name
        var_dict[symbol] = old


def _get_deprecation_severity():
    """Returns the warnings.simplefilter action for DrakeDeprecationWarning."""
    # This is used for controlling the severity of deprecation messages during
    # runtime. Note that the same literal string name for the environment
    # variable is used for both C++ code and Python code, so keep the two in
    # sync.
    severity = os.environ.get("DRAKE_DEPRECATION_RUNTIME_SEVERITY")
    if severity is None:
        return "once"

    if severity not in ("error", "ignore"):
        warnings.warn(
            "DRAKE_DEPRECATION_RUNTIME_SEVERITY is set to an unrecognized"
            f" value {severity!r}. Deprecation messages will be emitted"
            " as warnings.",
            stacklevel=2,
        )
        return "once"

    return severity


warnings.simplefilter(_get_deprecation_severity(), DrakeDeprecationWarning)
_installed_numpy_warning_filters = False

# Used to enforce presence of YYYY-MM-DD timestamp for deprecation.
_date_pattern = re.compile(r"\d\d\d\d\-\d\d\-\d\d")



import flags
import numpy
import pydrake.autodiffutils
import pydrake.common
import pydrake.common.value
import pydrake.math
import pydrake.symbolic
import pydrake.systems.framework
import pydrake.trajectories
import scipy.sparse
from pydrake.common.cpp_template import Adder_ as Adder_, AffineSystem_ as AffineSystem_, BusCreator_ as BusCreator_, BusSelector_ as BusSelector_, ConstantValueSource_ as ConstantValueSource_, ConstantVectorSource_ as ConstantVectorSource_, Demultiplexer_ as Demultiplexer_, DiscreteDerivative_ as DiscreteDerivative_, DiscreteTimeDelay_ as DiscreteTimeDelay_, DiscreteTimeIntegrator_ as DiscreteTimeIntegrator_, FirstOrderLowPassFilter_ as FirstOrderLowPassFilter_, Gain_ as Gain_, Integrator_ as Integrator_, LinearSystem_ as LinearSystem_, LinearTransformDensity_ as LinearTransformDensity_, MatrixGain_ as MatrixGain_, MultilayerPerceptron_ as MultilayerPerceptron_, Multiplexer_ as Multiplexer_, PassThrough_ as PassThrough_, PortSwitch_ as PortSwitch_, Saturation_ as Saturation_, Selector_ as Selector_, SharedPointerSystem_ as SharedPointerSystem_, Sine_ as Sine_, SparseMatrixGain_ as SparseMatrixGain_, StateInterpolatorWithDiscreteDerivative_ as StateInterpolatorWithDiscreteDerivative_, SymbolicVectorSystem_ as SymbolicVectorSystem_, TrajectoryAffineSystem_ as TrajectoryAffineSystem_, TrajectoryLinearSystem_ as TrajectoryLinearSystem_, TrajectorySource_ as TrajectorySource_, VectorLogSink_ as VectorLogSink_, VectorLog_ as VectorLog_, WrapToSystem_ as WrapToSystem_, ZeroOrderHold_ as ZeroOrderHold_
from typing import Any, Callable, ClassVar, overload

class Adder(pydrake.systems.framework.LeafSystem):
    def __init__(self, num_inputs: int, size: int) -> None: ...

class Adder_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, size: int) -> None: ...

class Adder_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, size: int) -> None: ...

class AffineSystem(pydrake.systems.framework.LeafSystem):
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ..., time_period: float = ...) -> None: ...
    def A(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def B(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def C(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def D(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def UpdateCoefficients(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ...) -> None: ...
    def configure_default_state(self, x0: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def num_inputs(self) -> int: ...
    def num_outputs(self) -> int: ...
    def num_states(self) -> int: ...
    def time_period(self) -> float: ...
    def y0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...

class AffineSystem_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ..., time_period: float = ...) -> None: ...
    def A(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def B(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def C(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def D(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def UpdateCoefficients(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ...) -> None: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def num_inputs(self) -> int: ...
    def num_outputs(self) -> int: ...
    def num_states(self) -> int: ...
    def time_period(self) -> float: ...
    def y0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...

class AffineSystem_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ..., time_period: float = ...) -> None: ...
    def A(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def B(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def C(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def D(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def UpdateCoefficients(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ...) -> None: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def num_inputs(self) -> int: ...
    def num_outputs(self) -> int: ...
    def num_states(self) -> int: ...
    def time_period(self) -> float: ...
    def y0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...

class BarycentricMeshSystem(pydrake.systems.framework.LeafSystem):
    def __init__(self, arg0: pydrake.math.BarycentricMesh, arg1: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def get_mesh(self) -> pydrake.math.BarycentricMesh: ...
    def get_output_values(self) -> numpy.ndarray[numpy.float64[m, n]]: ...

class BusCreator(pydrake.systems.framework.LeafSystem):
    def __init__(self, output_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.InputPort: ...
    def DeclareVectorInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.InputPort: ...

class BusCreator_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, output_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def DeclareVectorInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...

class BusCreator_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, output_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.InputPort_TExpressionU: ...
    def DeclareVectorInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.InputPort_TExpressionU: ...

class BusSelector(pydrake.systems.framework.LeafSystem):
    def __init__(self, input_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.OutputPort: ...
    def DeclareVectorOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.OutputPort: ...

class BusSelector_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...
    def DeclareVectorOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...

class BusSelector_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.OutputPort_TExpressionU: ...
    def DeclareVectorOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.OutputPort_TExpressionU: ...

class ConstantValueSource(pydrake.systems.framework.LeafSystem):
    def __init__(self, value: pydrake.common.value.AbstractValue) -> None: ...

class ConstantValueSource_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value: pydrake.common.value.AbstractValue) -> None: ...

class ConstantValueSource_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value: pydrake.common.value.AbstractValue) -> None: ...

class ConstantVectorSource(pydrake.systems.framework.LeafSystem):
    def __init__(self, source_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def get_mutable_source_value(self, context: pydrake.systems.framework.Context) -> pydrake.systems.framework.BasicVector: ...
    def get_source_value(self, context: pydrake.systems.framework.Context) -> pydrake.systems.framework.BasicVector: ...

class ConstantVectorSource_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, source_value: numpy.ndarray[object[m, 1]]) -> None: ...
    def get_mutable_source_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> pydrake.systems.framework.BasicVector_TAutoDiffXdU: ...
    def get_source_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> pydrake.systems.framework.BasicVector_TAutoDiffXdU: ...

class ConstantVectorSource_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, source_value: numpy.ndarray[object[m, 1]]) -> None: ...
    def get_mutable_source_value(self, context: pydrake.systems.framework.Context_TExpressionU) -> pydrake.systems.framework.BasicVector_TExpressionU: ...
    def get_source_value(self, context: pydrake.systems.framework.Context_TExpressionU) -> pydrake.systems.framework.BasicVector_TExpressionU: ...

class Demultiplexer(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, size: int, output_ports_size: int = ...) -> None: ...
    @overload
    def __init__(self, output_ports_sizes: list[int]) -> None: ...
    def get_output_ports_sizes(self) -> list[int]: ...

class Demultiplexer_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int, output_ports_size: int = ...) -> None: ...
    @overload
    def __init__(self, output_ports_sizes: list[int]) -> None: ...
    def get_output_ports_sizes(self) -> list[int]: ...

class Demultiplexer_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int, output_ports_size: int = ...) -> None: ...
    @overload
    def __init__(self, output_ports_sizes: list[int]) -> None: ...
    def get_output_ports_sizes(self) -> list[int]: ...

class DiscreteDerivative(pydrake.systems.framework.LeafSystem):
    def __init__(self, num_inputs: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    def suppress_initial_transient(self) -> bool: ...
    def time_step(self) -> float: ...

class DiscreteDerivative_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    def suppress_initial_transient(self) -> bool: ...
    def time_step(self) -> float: ...

class DiscreteDerivative_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    def suppress_initial_transient(self) -> bool: ...
    def time_step(self) -> float: ...

class DiscreteTimeDelay(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, vector_size: int) -> None: ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class DiscreteTimeDelay_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, vector_size: int) -> None: ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class DiscreteTimeDelay_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, vector_size: int) -> None: ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class DiscreteTimeIntegrator(pydrake.systems.framework.LeafSystem):
    def __init__(self, size: int, time_step: float) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context, value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def time_step(self) -> float: ...

class DiscreteTimeIntegrator_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, size: int, time_step: float) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, value: numpy.ndarray[object[m, 1]]) -> None: ...
    def time_step(self) -> float: ...

class DiscreteTimeIntegrator_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, size: int, time_step: float) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TExpressionU, value: numpy.ndarray[object[m, 1]]) -> None: ...
    def time_step(self) -> float: ...

class FirstOrderLowPassFilter(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, time_constant: float, size: int = ...) -> None: ...
    @overload
    def __init__(self, time_constants: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def get_time_constant(self) -> float: ...
    def get_time_constants_vector(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def set_initial_output_value(self, arg0: pydrake.systems.framework.Context, arg1: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class FirstOrderLowPassFilter_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time_constant: float, size: int = ...) -> None: ...
    @overload
    def __init__(self, time_constants: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def get_time_constant(self) -> float: ...
    def get_time_constants_vector(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def set_initial_output_value(self, arg0: pydrake.systems.framework.Context_TAutoDiffXdU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...

class FirstOrderLowPassFilter_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time_constant: float, size: int = ...) -> None: ...
    @overload
    def __init__(self, time_constants: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def get_time_constant(self) -> float: ...
    def get_time_constants_vector(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def set_initial_output_value(self, arg0: pydrake.systems.framework.Context_TExpressionU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...

class Gain(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, k: float, size: int) -> None: ...
    @overload
    def __init__(self, k: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class Gain_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, k: float, size: int) -> None: ...
    @overload
    def __init__(self, k: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class Gain_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, k: float, size: int) -> None: ...
    @overload
    def __init__(self, k: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class Integrator(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_default_integral_value(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context, value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class Integrator_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_default_integral_value(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, value: numpy.ndarray[object[m, 1]]) -> None: ...

class Integrator_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_default_integral_value(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TExpressionU, value: numpy.ndarray[object[m, 1]]) -> None: ...

class LinearSystem(AffineSystem):
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., time_period: float = ...) -> None: ...

class LinearSystem_𝓣AutoDiffXd𝓤(AffineSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., time_period: float = ...) -> None: ...

class LinearSystem_𝓣Expression𝓤(AffineSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., time_period: float = ...) -> None: ...

class LinearTransformDensity(pydrake.systems.framework.LeafSystem):
    def __init__(self, distribution: pydrake.common.RandomDistribution, input_size: int, output_size: int) -> None: ...
    def CalcDensity(self, context: pydrake.systems.framework.Context) -> float: ...
    def FixConstantA(self, context: pydrake.systems.framework.Context, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> pydrake.systems.framework.FixedInputPortValue: ...
    def FixConstantB(self, context: pydrake.systems.framework.Context, b: numpy.ndarray[numpy.float64[m, 1]]) -> pydrake.systems.framework.FixedInputPortValue: ...
    def get_distribution(self) -> pydrake.common.RandomDistribution: ...
    def get_input_port_A(self) -> pydrake.systems.framework.InputPort: ...
    def get_input_port_b(self) -> pydrake.systems.framework.InputPort: ...
    def get_input_port_w_in(self) -> pydrake.systems.framework.InputPort: ...
    def get_output_port_w_out(self) -> pydrake.systems.framework.OutputPort: ...
    def get_output_port_w_out_density(self) -> pydrake.systems.framework.OutputPort: ...

class LinearTransformDensity_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, distribution: pydrake.common.RandomDistribution, input_size: int, output_size: int) -> None: ...
    def CalcDensity(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def FixConstantA(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, A: numpy.ndarray[object[m, n], flags.f_contiguous]) -> pydrake.systems.framework.FixedInputPortValue: ...
    def FixConstantB(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, b: numpy.ndarray[object[m, 1]]) -> pydrake.systems.framework.FixedInputPortValue: ...
    def get_distribution(self) -> pydrake.common.RandomDistribution: ...
    def get_input_port_A(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_input_port_b(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_input_port_w_in(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_output_port_w_out(self) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...
    def get_output_port_w_out_density(self) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...

class MatrixGain(LinearSystem):
    def __init__(self, D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...

class MatrixGain_𝓣AutoDiffXd𝓤(LinearSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...

class MatrixGain_𝓣Expression𝓤(LinearSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...

class MultilayerPerceptron(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, layers: list[int], activation_type: PerceptronActivationType = ...) -> None: ...
    @overload
    def __init__(self, layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    @overload
    def __init__(self, use_sin_cos_for_input: list[bool], remaining_layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    def Backpropagation(self, context: pydrake.systems.framework.Context, X: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous], loss: Callable[[numpy.ndarray[numpy.float64[m, n], flags.f_contiguous], numpy.ndarray[numpy.float64[m, n], flags.writeable, flags.f_contiguous] | None], float], dloss_dparams: numpy.ndarray[numpy.float64[m, 1], flags.writeable] | None) -> float: ...
    def BackpropagationMeanSquaredError(self, context: pydrake.systems.framework.Context, X: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous], Y_desired: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous], dloss_dparams: numpy.ndarray[numpy.float64[m, 1], flags.writeable] | None) -> float: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context, X: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous], Y: numpy.ndarray[numpy.float64[m, n], flags.writeable, flags.f_contiguous] | None, dYdX: numpy.ndarray[numpy.float64[m, n], flags.writeable, flags.f_contiguous] | None = ...) -> None: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context, X: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> numpy.ndarray[numpy.float64[m, n]]: ...
    @overload
    def BatchOutput(self, context, X, Y) -> Any: ...
    @overload
    def GetBiases(self, context: pydrake.systems.framework.Context, layer: int) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    @overload
    def GetBiases(self, params: numpy.ndarray[numpy.float64[m, 1]], layer: int) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def GetMutableParameters(self, context: pydrake.systems.framework.Context) -> numpy.ndarray[numpy.float64[m, 1], flags.writeable]: ...
    def GetParameters(self, context: pydrake.systems.framework.Context) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    @overload
    def GetWeights(self, context: pydrake.systems.framework.Context, layer: int) -> numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]: ...
    @overload
    def GetWeights(self, params: numpy.ndarray[numpy.float64[m, 1]], layer: int) -> numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]: ...
    @overload
    def SetBiases(self, context: pydrake.systems.framework.Context, layer: int, b: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def SetBiases(self, params: numpy.ndarray[numpy.float64[m, 1], flags.writeable] | None, layer: int, b: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def SetParameters(self, context: pydrake.systems.framework.Context, params: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def SetWeights(self, context: pydrake.systems.framework.Context, layer: int, W: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def SetWeights(self, params: numpy.ndarray[numpy.float64[m, 1], flags.writeable] | None, layer: int, W: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def activation_type(self, layer: int) -> PerceptronActivationType: ...
    def layers(self) -> list[int]: ...
    def num_parameters(self) -> int: ...

class MultilayerPerceptron_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, layers: list[int], activation_type: PerceptronActivationType = ...) -> None: ...
    @overload
    def __init__(self, layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    @overload
    def __init__(self, use_sin_cos_for_input: list[bool], remaining_layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    def Backpropagation(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous], loss: Callable[[numpy.ndarray[object[m, n], flags.f_contiguous], numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None], pydrake.autodiffutils.AutoDiffXd], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.autodiffutils.AutoDiffXd: ...
    def BackpropagationMeanSquaredError(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y_desired: numpy.ndarray[object[m, n], flags.f_contiguous], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None, dYdX: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None = ...) -> None: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous]) -> numpy.ndarray[object[m, n]]: ...
    @overload
    def BatchOutput(self, context, X, Y) -> Any: ...
    @overload
    def GetBiases(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetBiases(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, 1]]: ...
    def GetMutableParameters(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> numpy.ndarray[object[m, 1], flags.writeable]: ...
    def GetParameters(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetWeights(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def GetWeights(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def SetBiases(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetBiases(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    def SetParameters(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, params: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetWeights(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def SetWeights(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def activation_type(self, layer: int) -> PerceptronActivationType: ...
    def layers(self) -> list[int]: ...
    def num_parameters(self) -> int: ...

class MultilayerPerceptron_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, layers: list[int], activation_type: PerceptronActivationType = ...) -> None: ...
    @overload
    def __init__(self, layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    @overload
    def __init__(self, use_sin_cos_for_input: list[bool], remaining_layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    def Backpropagation(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous], loss: Callable[[numpy.ndarray[object[m, n], flags.f_contiguous], numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None], pydrake.symbolic.Expression], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.symbolic.Expression: ...
    def BackpropagationMeanSquaredError(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y_desired: numpy.ndarray[object[m, n], flags.f_contiguous], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.symbolic.Expression: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None, dYdX: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None = ...) -> None: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous]) -> numpy.ndarray[object[m, n]]: ...
    @overload
    def BatchOutput(self, context, X, Y) -> Any: ...
    @overload
    def GetBiases(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetBiases(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, 1]]: ...
    def GetMutableParameters(self, context: pydrake.systems.framework.Context_TExpressionU) -> numpy.ndarray[object[m, 1], flags.writeable]: ...
    def GetParameters(self, context: pydrake.systems.framework.Context_TExpressionU) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetWeights(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def GetWeights(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def SetBiases(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetBiases(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    def SetParameters(self, context: pydrake.systems.framework.Context_TExpressionU, params: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetWeights(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def SetWeights(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def activation_type(self, layer: int) -> PerceptronActivationType: ...
    def layers(self) -> list[int]: ...
    def num_parameters(self) -> int: ...

class Multiplexer(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, num_scalar_inputs: int) -> None: ...
    @overload
    def __init__(self, input_sizes: list[int]) -> None: ...
    @overload
    def __init__(self, model_vector: pydrake.systems.framework.BasicVector) -> None: ...

class Multiplexer_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, num_scalar_inputs: int) -> None: ...
    @overload
    def __init__(self, input_sizes: list[int]) -> None: ...
    @overload
    def __init__(self, model_vector: pydrake.systems.framework.BasicVector_TAutoDiffXdU) -> None: ...

class Multiplexer_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, num_scalar_inputs: int) -> None: ...
    @overload
    def __init__(self, input_sizes: list[int]) -> None: ...
    @overload
    def __init__(self, model_vector: pydrake.systems.framework.BasicVector_TExpressionU) -> None: ...

class PassThrough(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, vector_size: int) -> None: ...
    @overload
    def __init__(self, value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def __init__(self, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class PassThrough_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, vector_size: int) -> None: ...
    @overload
    def __init__(self, value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def __init__(self, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class PassThrough_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, vector_size: int) -> None: ...
    @overload
    def __init__(self, value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def __init__(self, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class PerceptronActivationType:
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    kIdentity: ClassVar[PerceptronActivationType] = ...
    kReLU: ClassVar[PerceptronActivationType] = ...
    kTanh: ClassVar[PerceptronActivationType] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class PortSwitch(pydrake.systems.framework.LeafSystem):
    def __init__(self, vector_size: int) -> None: ...
    def DeclareInputPort(self, name: str) -> pydrake.systems.framework.InputPort: ...
    def get_port_selector_input_port(self) -> pydrake.systems.framework.InputPort: ...

class PortSwitch_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, vector_size: int) -> None: ...
    def DeclareInputPort(self, name: str) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_port_selector_input_port(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...

class PortSwitch_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, vector_size: int) -> None: ...
    def DeclareInputPort(self, name: str) -> pydrake.systems.framework.InputPort_TExpressionU: ...
    def get_port_selector_input_port(self) -> pydrake.systems.framework.InputPort_TExpressionU: ...

class RandomSource(pydrake.systems.framework.LeafSystem):
    def __init__(self, distribution: pydrake.common.RandomDistribution, num_outputs: int, sampling_interval_sec: float) -> None: ...

class Saturation(pydrake.systems.framework.LeafSystem):
    def __init__(self, min_value: numpy.ndarray[numpy.float64[m, 1]], max_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class Saturation_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, min_value: numpy.ndarray[object[m, 1]], max_value: numpy.ndarray[object[m, 1]]) -> None: ...

class Saturation_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, min_value: numpy.ndarray[object[m, 1]], max_value: numpy.ndarray[object[m, 1]]) -> None: ...

class Selector(pydrake.systems.framework.LeafSystem):
    def __init__(self, params: SelectorParams) -> None: ...

class SelectorParams:
    class InputPortParams:
        __fields__: ClassVar[tuple] = ...  # read-only
        name: str | None
        size: int
        def __init__(self, **kwargs) -> None: ...
        def __copy__(self) -> SelectorParams.InputPortParams: ...
        def __deepcopy__(self, arg0: dict) -> SelectorParams.InputPortParams: ...

    class OutputPortParams:
        __fields__: ClassVar[tuple] = ...  # read-only
        name: str | None
        selections: list[SelectorParams.OutputSelection]
        def __init__(self, **kwargs) -> None: ...
        def __copy__(self) -> SelectorParams.OutputPortParams: ...
        def __deepcopy__(self, arg0: dict) -> SelectorParams.OutputPortParams: ...

    class OutputSelection:
        __fields__: ClassVar[tuple] = ...  # read-only
        input_offset: int
        input_port_index: int
        def __init__(self, **kwargs) -> None: ...
        def __copy__(self) -> SelectorParams.OutputSelection: ...
        def __deepcopy__(self, arg0: dict) -> SelectorParams.OutputSelection: ...
    __fields__: ClassVar[tuple] = ...  # read-only
    inputs: list[SelectorParams.InputPortParams]
    outputs: list[SelectorParams.OutputPortParams]
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> SelectorParams: ...
    def __deepcopy__(self, arg0: dict) -> SelectorParams: ...

class Selector_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, params: SelectorParams) -> None: ...

class Selector_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, params: SelectorParams) -> None: ...

class SharedPointerSystem(pydrake.systems.framework.LeafSystem):
    def __init__(self, value_to_hold: object) -> None: ...
    @staticmethod
    def AddToBuilder(builder: pydrake.systems.framework.DiagramBuilder, value_to_hold: object) -> object: ...
    def get(self) -> object: ...

class SharedPointerSystem_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value_to_hold: object) -> None: ...
    @staticmethod
    def AddToBuilder(builder: pydrake.systems.framework.DiagramBuilder_TAutoDiffXdU, value_to_hold: object) -> object: ...
    def get(self) -> object: ...

class SharedPointerSystem_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value_to_hold: object) -> None: ...
    @staticmethod
    def AddToBuilder(builder: pydrake.systems.framework.DiagramBuilder_TExpressionU, value_to_hold: object) -> object: ...
    def get(self) -> object: ...

class Sine(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, amplitude: float, frequency: float, phase: float, size: int, is_time_based: bool = ...) -> None: ...
    @overload
    def __init__(self, amplitudes: numpy.ndarray[numpy.float64[m, 1]], frequencies: numpy.ndarray[numpy.float64[m, 1]], phases: numpy.ndarray[numpy.float64[m, 1]], is_time_based: bool = ...) -> None: ...

class Sine_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, amplitude: float, frequency: float, phase: float, size: int, is_time_based: bool = ...) -> None: ...
    @overload
    def __init__(self, amplitudes: numpy.ndarray[numpy.float64[m, 1]], frequencies: numpy.ndarray[numpy.float64[m, 1]], phases: numpy.ndarray[numpy.float64[m, 1]], is_time_based: bool = ...) -> None: ...

class Sine_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, amplitude: float, frequency: float, phase: float, size: int, is_time_based: bool = ...) -> None: ...
    @overload
    def __init__(self, amplitudes: numpy.ndarray[numpy.float64[m, 1]], frequencies: numpy.ndarray[numpy.float64[m, 1]], phases: numpy.ndarray[numpy.float64[m, 1]], is_time_based: bool = ...) -> None: ...

class SparseMatrixGain(pydrake.systems.framework.LeafSystem):
    def __init__(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...
    def D(self) -> scipy.sparse.csc_matrix[numpy.float64]: ...
    def set_D(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...

class SparseMatrixGain_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...
    def D(self) -> scipy.sparse.csc_matrix[numpy.float64]: ...
    def set_D(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...

class SparseMatrixGain_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...
    def D(self) -> scipy.sparse.csc_matrix[numpy.float64]: ...
    def set_D(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...

class StateInterpolatorWithDiscreteDerivative(pydrake.systems.framework.Diagram):
    def __init__(self, num_positions: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    @overload
    def set_initial_position(self, context: pydrake.systems.framework.Context, position: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def set_initial_position(self, state: pydrake.systems.framework.State, position: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def suppress_initial_transient(self) -> bool: ...

class StateInterpolatorWithDiscreteDerivative_𝓣AutoDiffXd𝓤(pydrake.systems.framework.Diagram_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_positions: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    @overload
    def set_initial_position(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def set_initial_position(self, state: pydrake.systems.framework.State_TAutoDiffXdU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    def suppress_initial_transient(self) -> bool: ...

class StateInterpolatorWithDiscreteDerivative_𝓣Expression𝓤(pydrake.systems.framework.Diagram_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_positions: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    @overload
    def set_initial_position(self, context: pydrake.systems.framework.Context_TExpressionU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def set_initial_position(self, state: pydrake.systems.framework.State_TExpressionU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    def suppress_initial_transient(self) -> bool: ...

class SymbolicVectorSystem(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., parameter: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    def dynamics_for_variable(self, var: pydrake.symbolic.Variable) -> pydrake.symbolic.Expression: ...

class SymbolicVectorSystem_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., parameter: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    def dynamics_for_variable(self, var: pydrake.symbolic.Variable) -> pydrake.symbolic.Expression: ...

class SymbolicVectorSystem_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., parameter: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    def dynamics_for_variable(self, var: pydrake.symbolic.Variable) -> pydrake.symbolic.Expression: ...

class TrajectoryAffineSystem(pydrake.systems.framework.LeafSystem):
    def __init__(self, A: pydrake.trajectories.Trajectory, B: pydrake.trajectories.Trajectory, f0: pydrake.trajectories.Trajectory, C: pydrake.trajectories.Trajectory, D: pydrake.trajectories.Trajectory, y0: pydrake.trajectories.Trajectory, time_period: float = ...) -> None: ...
    def A(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def B(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def C(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def D(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def configure_default_state(self, x0: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self, arg0: float) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def time_period(self) -> float: ...
    def y0(self, arg0: float) -> numpy.ndarray[numpy.float64[m, 1]]: ...

class TrajectoryAffineSystem_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: pydrake.trajectories.Trajectory, B: pydrake.trajectories.Trajectory, f0: pydrake.trajectories.Trajectory, C: pydrake.trajectories.Trajectory, D: pydrake.trajectories.Trajectory, y0: pydrake.trajectories.Trajectory, time_period: float = ...) -> None: ...
    def A(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def B(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def C(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def D(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, 1]]: ...
    def time_period(self) -> float: ...
    def y0(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, 1]]: ...

class TrajectoryLinearSystem(pydrake.systems.framework.LeafSystem):
    def __init__(self, A: pydrake.trajectories.Trajectory, B: pydrake.trajectories.Trajectory, C: pydrake.trajectories.Trajectory, D: pydrake.trajectories.Trajectory, time_period: float = ...) -> None: ...
    def A(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def B(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def C(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def D(self, arg0: float) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def configure_default_state(self, x0: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def time_period(self) -> float: ...

class TrajectoryLinearSystem_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: pydrake.trajectories.Trajectory, B: pydrake.trajectories.Trajectory, C: pydrake.trajectories.Trajectory, D: pydrake.trajectories.Trajectory, time_period: float = ...) -> None: ...
    def A(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def B(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def C(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def D(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def time_period(self) -> float: ...

class TrajectorySource(pydrake.systems.framework.LeafSystem):
    def __init__(self, trajectory: pydrake.trajectories.Trajectory, output_derivative_order: int = ..., zero_derivatives_beyond_limits: bool = ...) -> None: ...
    def UpdateTrajectory(self, trajectory: pydrake.trajectories.Trajectory) -> None: ...

class TrajectorySource_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: pydrake.trajectories.Trajectory_TAutoDiffXdU, output_derivative_order: int = ..., zero_derivatives_beyond_limits: bool = ...) -> None: ...
    def UpdateTrajectory(self, trajectory: pydrake.trajectories.Trajectory_TAutoDiffXdU) -> None: ...

class TrajectorySource_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: pydrake.trajectories.Trajectory_TExpressionU, output_derivative_order: int = ..., zero_derivatives_beyond_limits: bool = ...) -> None: ...
    def UpdateTrajectory(self, trajectory: pydrake.trajectories.Trajectory_TExpressionU) -> None: ...

class VectorLog:
    kDefaultCapacity: ClassVar[int] = ...  # read-only
    def __init__(self, input_size: int) -> None: ...
    def AddData(self, time: float, sample: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def Clear(self) -> None: ...
    def Reserve(self, arg0: int) -> None: ...
    def data(self) -> numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]: ...
    def get_input_size(self) -> int: ...
    def num_samples(self) -> int: ...
    def sample_times(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...

class VectorLogSink(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, input_size: int, publish_period: float = ...) -> None: ...
    @overload
    def __init__(self, input_size: int, publish_triggers: set[pydrake.systems.framework.TriggerType], publish_period: float = ...) -> None: ...
    def FindLog(self, context: pydrake.systems.framework.Context) -> VectorLog: ...
    def FindMutableLog(self, context: pydrake.systems.framework.Context) -> VectorLog: ...
    def GetLog(self, context: pydrake.systems.framework.Context) -> VectorLog: ...
    def GetMutableLog(self, context: pydrake.systems.framework.Context) -> VectorLog: ...

class VectorLogSink_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, input_size: int, publish_period: float = ...) -> None: ...
    @overload
    def __init__(self, input_size: int, publish_triggers: set[pydrake.systems.framework.TriggerType], publish_period: float = ...) -> None: ...
    def FindLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...
    def FindMutableLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...
    def GetLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...
    def GetMutableLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...

class VectorLogSink_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, input_size: int, publish_period: float = ...) -> None: ...
    @overload
    def __init__(self, input_size: int, publish_triggers: set[pydrake.systems.framework.TriggerType], publish_period: float = ...) -> None: ...
    def FindLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...
    def FindMutableLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...
    def GetLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...
    def GetMutableLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...

class VectorLog_𝓣AutoDiffXd𝓤:
    kDefaultCapacity: ClassVar[int] = ...  # read-only
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_size: int) -> None: ...
    def AddData(self, time: pydrake.autodiffutils.AutoDiffXd, sample: numpy.ndarray[object[m, 1]]) -> None: ...
    def Clear(self) -> None: ...
    def Reserve(self, arg0: int) -> None: ...
    def data(self) -> numpy.ndarray[object[m, n]]: ...
    def get_input_size(self) -> int: ...
    def num_samples(self) -> int: ...
    def sample_times(self) -> numpy.ndarray[object[m, 1]]: ...

class VectorLog_𝓣Expression𝓤:
    kDefaultCapacity: ClassVar[int] = ...  # read-only
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_size: int) -> None: ...
    def AddData(self, time: pydrake.symbolic.Expression, sample: numpy.ndarray[object[m, 1]]) -> None: ...
    def Clear(self) -> None: ...
    def Reserve(self, arg0: int) -> None: ...
    def data(self) -> numpy.ndarray[object[m, n]]: ...
    def get_input_size(self) -> int: ...
    def num_samples(self) -> int: ...
    def sample_times(self) -> numpy.ndarray[object[m, 1]]: ...

class WrapToSystem(pydrake.systems.framework.LeafSystem):
    def __init__(self, arg0: int) -> None: ...
    def set_interval(self, arg0: int, arg1: float, arg2: float) -> None: ...

class WrapToSystem_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, arg0: int) -> None: ...
    def set_interval(self, arg0: int, arg1: pydrake.autodiffutils.AutoDiffXd, arg2: pydrake.autodiffutils.AutoDiffXd) -> None: ...

class WrapToSystem_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, arg0: int) -> None: ...
    def set_interval(self, arg0: int, arg1: pydrake.symbolic.Expression, arg2: pydrake.symbolic.Expression) -> None: ...

class ZeroOrderHold(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, period_sec: float, vector_size: int, offset_sec: float = ...) -> None: ...
    @overload
    def __init__(self, period_sec: float, abstract_model_value: pydrake.common.value.AbstractValue, offset_sec: float = ...) -> None: ...
    def SetVectorState(self, arg0: pydrake.systems.framework.Context, arg1: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def offset(self) -> float: ...
    def period(self) -> float: ...

class ZeroOrderHold_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, period_sec: float, vector_size: int, offset_sec: float = ...) -> None: ...
    @overload
    def __init__(self, period_sec: float, abstract_model_value: pydrake.common.value.AbstractValue, offset_sec: float = ...) -> None: ...
    def SetVectorState(self, arg0: pydrake.systems.framework.Context_TAutoDiffXdU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...
    def offset(self) -> float: ...
    def period(self) -> float: ...

class ZeroOrderHold_𝓣Expression𝓤(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, period_sec: float, vector_size: int, offset_sec: float = ...) -> None: ...
    @overload
    def __init__(self, period_sec: float, abstract_model_value: pydrake.common.value.AbstractValue, offset_sec: float = ...) -> None: ...
    def SetVectorState(self, arg0: pydrake.systems.framework.Context_TExpressionU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...
    def offset(self) -> float: ...
    def period(self) -> float: ...

class _TemporaryName_N5drake7systems10BusCreatorINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, output_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def DeclareVectorInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...

class _TemporaryName_N5drake7systems10BusCreatorINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, output_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.InputPort_TExpressionU: ...
    def DeclareVectorInputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.InputPort_TExpressionU: ...

class _TemporaryName_N5drake7systems10IntegratorINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_default_integral_value(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, value: numpy.ndarray[object[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems10IntegratorINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_default_integral_value(self, initial_value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TExpressionU, value: numpy.ndarray[object[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems10MatrixGainINS_2ad8AutoDiffEEE(LinearSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...

class _TemporaryName_N5drake7systems10MatrixGainINS_8symbolic10ExpressionEEE(LinearSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...

class _TemporaryName_N5drake7systems10PortSwitchINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, vector_size: int) -> None: ...
    def DeclareInputPort(self, name: str) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_port_selector_input_port(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...

class _TemporaryName_N5drake7systems10PortSwitchINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, vector_size: int) -> None: ...
    def DeclareInputPort(self, name: str) -> pydrake.systems.framework.InputPort_TExpressionU: ...
    def get_port_selector_input_port(self) -> pydrake.systems.framework.InputPort_TExpressionU: ...

class _TemporaryName_N5drake7systems10SaturationINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, min_value: numpy.ndarray[object[m, 1]], max_value: numpy.ndarray[object[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems10SaturationINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, min_value: numpy.ndarray[object[m, 1]], max_value: numpy.ndarray[object[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems11BusSelectorINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...
    def DeclareVectorOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...

class _TemporaryName_N5drake7systems11BusSelectorINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_port_name: str | pydrake.systems.framework.UseDefaultName = ...) -> None: ...
    def DeclareAbstractOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, model_value: pydrake.common.value.AbstractValue) -> pydrake.systems.framework.OutputPort_TExpressionU: ...
    def DeclareVectorOutputPort(self, name: str | pydrake.systems.framework.UseDefaultName, size: int) -> pydrake.systems.framework.OutputPort_TExpressionU: ...

class _TemporaryName_N5drake7systems11MultiplexerINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, num_scalar_inputs: int) -> None: ...
    @overload
    def __init__(self, input_sizes: list[int]) -> None: ...
    @overload
    def __init__(self, model_vector: pydrake.systems.framework.BasicVector_TAutoDiffXdU) -> None: ...

class _TemporaryName_N5drake7systems11MultiplexerINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, num_scalar_inputs: int) -> None: ...
    @overload
    def __init__(self, input_sizes: list[int]) -> None: ...
    @overload
    def __init__(self, model_vector: pydrake.systems.framework.BasicVector_TExpressionU) -> None: ...

class _TemporaryName_N5drake7systems11PassThroughINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, vector_size: int) -> None: ...
    @overload
    def __init__(self, value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def __init__(self, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class _TemporaryName_N5drake7systems11PassThroughINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, vector_size: int) -> None: ...
    @overload
    def __init__(self, value: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    @overload
    def __init__(self, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class _TemporaryName_N5drake7systems12AffineSystemINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ..., time_period: float = ...) -> None: ...
    def A(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def B(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def C(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def D(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def UpdateCoefficients(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ...) -> None: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def num_inputs(self) -> int: ...
    def num_outputs(self) -> int: ...
    def num_states(self) -> int: ...
    def time_period(self) -> float: ...
    def y0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...

class _TemporaryName_N5drake7systems12AffineSystemINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ..., time_period: float = ...) -> None: ...
    def A(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def B(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def C(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def D(self) -> numpy.ndarray[numpy.float64[m, n]]: ...
    def UpdateCoefficients(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., f0: numpy.ndarray[numpy.float64[m, 1]] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., y0: numpy.ndarray[numpy.float64[m, 1]] = ...) -> None: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def num_inputs(self) -> int: ...
    def num_outputs(self) -> int: ...
    def num_states(self) -> int: ...
    def time_period(self) -> float: ...
    def y0(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...

class _TemporaryName_N5drake7systems12LinearSystemINS_2ad8AutoDiffEEE(AffineSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., time_period: float = ...) -> None: ...

class _TemporaryName_N5drake7systems12LinearSystemINS_8symbolic10ExpressionEEE(AffineSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., B: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., C: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., D: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous] = ..., time_period: float = ...) -> None: ...

class _TemporaryName_N5drake7systems12WrapToSystemINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, arg0: int) -> None: ...
    def set_interval(self, arg0: int, arg1: pydrake.autodiffutils.AutoDiffXd, arg2: pydrake.autodiffutils.AutoDiffXd) -> None: ...

class _TemporaryName_N5drake7systems12WrapToSystemINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, arg0: int) -> None: ...
    def set_interval(self, arg0: int, arg1: pydrake.symbolic.Expression, arg2: pydrake.symbolic.Expression) -> None: ...

class _TemporaryName_N5drake7systems13DemultiplexerINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int, output_ports_size: int = ...) -> None: ...
    @overload
    def __init__(self, output_ports_sizes: list[int]) -> None: ...
    def get_output_ports_sizes(self) -> list[int]: ...

class _TemporaryName_N5drake7systems13DemultiplexerINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, size: int, output_ports_size: int = ...) -> None: ...
    @overload
    def __init__(self, output_ports_sizes: list[int]) -> None: ...
    def get_output_ports_sizes(self) -> list[int]: ...

class _TemporaryName_N5drake7systems13VectorLogSinkINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, input_size: int, publish_period: float = ...) -> None: ...
    @overload
    def __init__(self, input_size: int, publish_triggers: set[pydrake.systems.framework.TriggerType], publish_period: float = ...) -> None: ...
    def FindLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...
    def FindMutableLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...
    def GetLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...
    def GetMutableLog(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> VectorLog_TAutoDiffXdU: ...

class _TemporaryName_N5drake7systems13VectorLogSinkINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, input_size: int, publish_period: float = ...) -> None: ...
    @overload
    def __init__(self, input_size: int, publish_triggers: set[pydrake.systems.framework.TriggerType], publish_period: float = ...) -> None: ...
    def FindLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...
    def FindMutableLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...
    def GetLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...
    def GetMutableLog(self, context: pydrake.systems.framework.Context_TExpressionU) -> VectorLog_TExpressionU: ...

class _TemporaryName_N5drake7systems13ZeroOrderHoldINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, period_sec: float, vector_size: int, offset_sec: float = ...) -> None: ...
    @overload
    def __init__(self, period_sec: float, abstract_model_value: pydrake.common.value.AbstractValue, offset_sec: float = ...) -> None: ...
    def SetVectorState(self, arg0: pydrake.systems.framework.Context_TAutoDiffXdU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...
    def offset(self) -> float: ...
    def period(self) -> float: ...

class _TemporaryName_N5drake7systems13ZeroOrderHoldINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, period_sec: float, vector_size: int, offset_sec: float = ...) -> None: ...
    @overload
    def __init__(self, period_sec: float, abstract_model_value: pydrake.common.value.AbstractValue, offset_sec: float = ...) -> None: ...
    def SetVectorState(self, arg0: pydrake.systems.framework.Context_TExpressionU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...
    def offset(self) -> float: ...
    def period(self) -> float: ...

class _TemporaryName_N5drake7systems16SparseMatrixGainINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...
    def D(self) -> scipy.sparse.csc_matrix[numpy.float64]: ...
    def set_D(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...

class _TemporaryName_N5drake7systems16SparseMatrixGainINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...
    def D(self) -> scipy.sparse.csc_matrix[numpy.float64]: ...
    def set_D(self, D: scipy.sparse.csc_matrix[numpy.float64]) -> None: ...

class _TemporaryName_N5drake7systems16TrajectorySourceINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: pydrake.trajectories.Trajectory_TAutoDiffXdU, output_derivative_order: int = ..., zero_derivatives_beyond_limits: bool = ...) -> None: ...
    def UpdateTrajectory(self, trajectory: pydrake.trajectories.Trajectory_TAutoDiffXdU) -> None: ...

class _TemporaryName_N5drake7systems16TrajectorySourceINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, trajectory: pydrake.trajectories.Trajectory_TExpressionU, output_derivative_order: int = ..., zero_derivatives_beyond_limits: bool = ...) -> None: ...
    def UpdateTrajectory(self, trajectory: pydrake.trajectories.Trajectory_TExpressionU) -> None: ...

class _TemporaryName_N5drake7systems17DiscreteTimeDelayINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, vector_size: int) -> None: ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class _TemporaryName_N5drake7systems17DiscreteTimeDelayINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, vector_size: int) -> None: ...
    @overload
    def __init__(self, update_sec: float, delay_time_steps: int, abstract_model_value: pydrake.common.value.AbstractValue) -> None: ...

class _TemporaryName_N5drake7systems18DiscreteDerivativeINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    def suppress_initial_transient(self) -> bool: ...
    def time_step(self) -> float: ...

class _TemporaryName_N5drake7systems18DiscreteDerivativeINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    def suppress_initial_transient(self) -> bool: ...
    def time_step(self) -> float: ...

class _TemporaryName_N5drake7systems19ConstantValueSourceINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value: pydrake.common.value.AbstractValue) -> None: ...

class _TemporaryName_N5drake7systems19ConstantValueSourceINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value: pydrake.common.value.AbstractValue) -> None: ...

class _TemporaryName_N5drake7systems19SharedPointerSystemINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value_to_hold: object) -> None: ...
    @staticmethod
    def AddToBuilder(builder: pydrake.systems.framework.DiagramBuilder_TAutoDiffXdU, value_to_hold: object) -> object: ...
    def get(self) -> object: ...

class _TemporaryName_N5drake7systems19SharedPointerSystemINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, value_to_hold: object) -> None: ...
    @staticmethod
    def AddToBuilder(builder: pydrake.systems.framework.DiagramBuilder_TExpressionU, value_to_hold: object) -> object: ...
    def get(self) -> object: ...

class _TemporaryName_N5drake7systems20ConstantVectorSourceINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, source_value: numpy.ndarray[object[m, 1]]) -> None: ...
    def get_mutable_source_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> pydrake.systems.framework.BasicVector_TAutoDiffXdU: ...
    def get_source_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> pydrake.systems.framework.BasicVector_TAutoDiffXdU: ...

class _TemporaryName_N5drake7systems20ConstantVectorSourceINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, source_value: numpy.ndarray[object[m, 1]]) -> None: ...
    def get_mutable_source_value(self, context: pydrake.systems.framework.Context_TExpressionU) -> pydrake.systems.framework.BasicVector_TExpressionU: ...
    def get_source_value(self, context: pydrake.systems.framework.Context_TExpressionU) -> pydrake.systems.framework.BasicVector_TExpressionU: ...

class _TemporaryName_N5drake7systems20MultilayerPerceptronINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, layers: list[int], activation_type: PerceptronActivationType = ...) -> None: ...
    @overload
    def __init__(self, layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    @overload
    def __init__(self, use_sin_cos_for_input: list[bool], remaining_layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    def Backpropagation(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous], loss: Callable[[numpy.ndarray[object[m, n], flags.f_contiguous], numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None], pydrake.autodiffutils.AutoDiffXd], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.autodiffutils.AutoDiffXd: ...
    def BackpropagationMeanSquaredError(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y_desired: numpy.ndarray[object[m, n], flags.f_contiguous], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.autodiffutils.AutoDiffXd: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None, dYdX: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None = ...) -> None: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, X: numpy.ndarray[object[m, n], flags.f_contiguous]) -> numpy.ndarray[object[m, n]]: ...
    @overload
    def BatchOutput(self, context, X, Y) -> Any: ...
    @overload
    def GetBiases(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetBiases(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, 1]]: ...
    def GetMutableParameters(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> numpy.ndarray[object[m, 1], flags.writeable]: ...
    def GetParameters(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetWeights(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def GetWeights(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def SetBiases(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetBiases(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    def SetParameters(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, params: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetWeights(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def SetWeights(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def activation_type(self, layer: int) -> PerceptronActivationType: ...
    def layers(self) -> list[int]: ...
    def num_parameters(self) -> int: ...

class _TemporaryName_N5drake7systems20MultilayerPerceptronINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, layers: list[int], activation_type: PerceptronActivationType = ...) -> None: ...
    @overload
    def __init__(self, layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    @overload
    def __init__(self, use_sin_cos_for_input: list[bool], remaining_layers: list[int], activation_types: list[PerceptronActivationType]) -> None: ...
    def Backpropagation(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous], loss: Callable[[numpy.ndarray[object[m, n], flags.f_contiguous], numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None], pydrake.symbolic.Expression], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.symbolic.Expression: ...
    def BackpropagationMeanSquaredError(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y_desired: numpy.ndarray[object[m, n], flags.f_contiguous], dloss_dparams: numpy.ndarray[object[m, 1], flags.writeable] | None) -> pydrake.symbolic.Expression: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous], Y: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None, dYdX: numpy.ndarray[object[m, n], flags.writeable, flags.f_contiguous] | None = ...) -> None: ...
    @overload
    def BatchOutput(self, context: pydrake.systems.framework.Context_TExpressionU, X: numpy.ndarray[object[m, n], flags.f_contiguous]) -> numpy.ndarray[object[m, n]]: ...
    @overload
    def BatchOutput(self, context, X, Y) -> Any: ...
    @overload
    def GetBiases(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetBiases(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, 1]]: ...
    def GetMutableParameters(self, context: pydrake.systems.framework.Context_TExpressionU) -> numpy.ndarray[object[m, 1], flags.writeable]: ...
    def GetParameters(self, context: pydrake.systems.framework.Context_TExpressionU) -> numpy.ndarray[object[m, 1]]: ...
    @overload
    def GetWeights(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def GetWeights(self, params: numpy.ndarray[object[m, 1]], layer: int) -> numpy.ndarray[object[m, n], flags.f_contiguous]: ...
    @overload
    def SetBiases(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetBiases(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, b: numpy.ndarray[object[m, 1]]) -> None: ...
    def SetParameters(self, context: pydrake.systems.framework.Context_TExpressionU, params: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def SetWeights(self, context: pydrake.systems.framework.Context_TExpressionU, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    @overload
    def SetWeights(self, params: numpy.ndarray[object[m, 1], flags.writeable] | None, layer: int, W: numpy.ndarray[object[m, n], flags.f_contiguous]) -> None: ...
    def activation_type(self, layer: int) -> PerceptronActivationType: ...
    def layers(self) -> list[int]: ...
    def num_parameters(self) -> int: ...

class _TemporaryName_N5drake7systems20SymbolicVectorSystemINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., parameter: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    def dynamics_for_variable(self, var: pydrake.symbolic.Variable) -> pydrake.symbolic.Expression: ...

class _TemporaryName_N5drake7systems20SymbolicVectorSystemINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    @overload
    def __init__(self, time: pydrake.symbolic.Variable | None = ..., state: numpy.ndarray[object[m, 1]] = ..., input: numpy.ndarray[object[m, 1]] = ..., parameter: numpy.ndarray[object[m, 1]] = ..., dynamics: numpy.ndarray[object[m, 1]] = ..., output: numpy.ndarray[object[m, 1]] = ..., time_period: float = ...) -> None: ...
    def dynamics_for_variable(self, var: pydrake.symbolic.Variable) -> pydrake.symbolic.Expression: ...

class _TemporaryName_N5drake7systems22DiscreteTimeIntegratorINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, size: int, time_step: float) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, value: numpy.ndarray[object[m, 1]]) -> None: ...
    def time_step(self) -> float: ...

class _TemporaryName_N5drake7systems22DiscreteTimeIntegratorINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, size: int, time_step: float) -> None: ...
    def set_integral_value(self, context: pydrake.systems.framework.Context_TExpressionU, value: numpy.ndarray[object[m, 1]]) -> None: ...
    def time_step(self) -> float: ...

class _TemporaryName_N5drake7systems22LinearTransformDensityINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, distribution: pydrake.common.RandomDistribution, input_size: int, output_size: int) -> None: ...
    def CalcDensity(self, context: pydrake.systems.framework.Context_TAutoDiffXdU) -> pydrake.autodiffutils.AutoDiffXd: ...
    def FixConstantA(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, A: numpy.ndarray[object[m, n], flags.f_contiguous]) -> pydrake.systems.framework.FixedInputPortValue: ...
    def FixConstantB(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, b: numpy.ndarray[object[m, 1]]) -> pydrake.systems.framework.FixedInputPortValue: ...
    def get_distribution(self) -> pydrake.common.RandomDistribution: ...
    def get_input_port_A(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_input_port_b(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_input_port_w_in(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def get_output_port_w_out(self) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...
    def get_output_port_w_out_density(self) -> pydrake.systems.framework.OutputPort_TAutoDiffXdU: ...

class _TemporaryName_N5drake7systems22TrajectoryAffineSystemINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: pydrake.trajectories.Trajectory, B: pydrake.trajectories.Trajectory, f0: pydrake.trajectories.Trajectory, C: pydrake.trajectories.Trajectory, D: pydrake.trajectories.Trajectory, y0: pydrake.trajectories.Trajectory, time_period: float = ...) -> None: ...
    def A(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def B(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def C(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def D(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def f0(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, 1]]: ...
    def time_period(self) -> float: ...
    def y0(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, 1]]: ...

class _TemporaryName_N5drake7systems22TrajectoryLinearSystemINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, A: pydrake.trajectories.Trajectory, B: pydrake.trajectories.Trajectory, C: pydrake.trajectories.Trajectory, D: pydrake.trajectories.Trajectory, time_period: float = ...) -> None: ...
    def A(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def B(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def C(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def D(self, arg0: pydrake.autodiffutils.AutoDiffXd) -> numpy.ndarray[object[m, n]]: ...
    def configure_default_state(self, x0: numpy.ndarray[object[m, 1]]) -> None: ...
    def configure_random_state(self, covariance: numpy.ndarray[numpy.float64[m, n], flags.f_contiguous]) -> None: ...
    def time_period(self) -> float: ...

class _TemporaryName_N5drake7systems23FirstOrderLowPassFilterINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time_constant: float, size: int = ...) -> None: ...
    @overload
    def __init__(self, time_constants: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def get_time_constant(self) -> float: ...
    def get_time_constants_vector(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def set_initial_output_value(self, arg0: pydrake.systems.framework.Context_TAutoDiffXdU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems23FirstOrderLowPassFilterINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, time_constant: float, size: int = ...) -> None: ...
    @overload
    def __init__(self, time_constants: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...
    def get_time_constant(self) -> float: ...
    def get_time_constants_vector(self) -> numpy.ndarray[numpy.float64[m, 1]]: ...
    def set_initial_output_value(self, arg0: pydrake.systems.framework.Context_TExpressionU, arg1: numpy.ndarray[object[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems39StateInterpolatorWithDiscreteDerivativeINS_2ad8AutoDiffEEE(pydrake.systems.framework.Diagram_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_positions: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    @overload
    def set_initial_position(self, context: pydrake.systems.framework.Context_TAutoDiffXdU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def set_initial_position(self, state: pydrake.systems.framework.State_TAutoDiffXdU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    def suppress_initial_transient(self) -> bool: ...

class _TemporaryName_N5drake7systems39StateInterpolatorWithDiscreteDerivativeINS_8symbolic10ExpressionEEE(pydrake.systems.framework.Diagram_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_positions: int, time_step: float, suppress_initial_transient: bool = ...) -> None: ...
    @overload
    def set_initial_position(self, context: pydrake.systems.framework.Context_TExpressionU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    @overload
    def set_initial_position(self, state: pydrake.systems.framework.State_TExpressionU, position: numpy.ndarray[object[m, 1]]) -> None: ...
    def suppress_initial_transient(self) -> bool: ...

class _TemporaryName_N5drake7systems4GainINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, k: float, size: int) -> None: ...
    @overload
    def __init__(self, k: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems4GainINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, k: float, size: int) -> None: ...
    @overload
    def __init__(self, k: numpy.ndarray[numpy.float64[m, 1]]) -> None: ...

class _TemporaryName_N5drake7systems4SineINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, amplitude: float, frequency: float, phase: float, size: int, is_time_based: bool = ...) -> None: ...
    @overload
    def __init__(self, amplitudes: numpy.ndarray[numpy.float64[m, 1]], frequencies: numpy.ndarray[numpy.float64[m, 1]], phases: numpy.ndarray[numpy.float64[m, 1]], is_time_based: bool = ...) -> None: ...

class _TemporaryName_N5drake7systems4SineINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    @overload
    def __init__(self, amplitude: float, frequency: float, phase: float, size: int, is_time_based: bool = ...) -> None: ...
    @overload
    def __init__(self, amplitudes: numpy.ndarray[numpy.float64[m, 1]], frequencies: numpy.ndarray[numpy.float64[m, 1]], phases: numpy.ndarray[numpy.float64[m, 1]], is_time_based: bool = ...) -> None: ...

class _TemporaryName_N5drake7systems5AdderINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, size: int) -> None: ...

class _TemporaryName_N5drake7systems5AdderINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, num_inputs: int, size: int) -> None: ...

class _TemporaryName_N5drake7systems8SelectorINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, params: SelectorParams) -> None: ...

class _TemporaryName_N5drake7systems8SelectorINS_8symbolic10ExpressionEEE(pydrake.systems.framework.LeafSystem_TExpressionU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, params: SelectorParams) -> None: ...

class _TemporaryName_N5drake7systems9VectorLogINS_2ad8AutoDiffEEE:
    kDefaultCapacity: ClassVar[int] = ...  # read-only
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_size: int) -> None: ...
    def AddData(self, time: pydrake.autodiffutils.AutoDiffXd, sample: numpy.ndarray[object[m, 1]]) -> None: ...
    def Clear(self) -> None: ...
    def Reserve(self, arg0: int) -> None: ...
    def data(self) -> numpy.ndarray[object[m, n]]: ...
    def get_input_size(self) -> int: ...
    def num_samples(self) -> int: ...
    def sample_times(self) -> numpy.ndarray[object[m, 1]]: ...

class _TemporaryName_N5drake7systems9VectorLogINS_8symbolic10ExpressionEEE:
    kDefaultCapacity: ClassVar[int] = ...  # read-only
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, input_size: int) -> None: ...
    def AddData(self, time: pydrake.symbolic.Expression, sample: numpy.ndarray[object[m, 1]]) -> None: ...
    def Clear(self) -> None: ...
    def Reserve(self, arg0: int) -> None: ...
    def data(self) -> numpy.ndarray[object[m, n]]: ...
    def get_input_size(self) -> int: ...
    def num_samples(self) -> int: ...
    def sample_times(self) -> numpy.ndarray[object[m, 1]]: ...

@overload
def AddRandomInputs(sampling_interval_sec: float, builder: pydrake.systems.framework.DiagramBuilder) -> int: ...
@overload
def AddRandomInputs(sampling_interval_sec: float, builder: pydrake.systems.framework.DiagramBuilder_TAutoDiffXdU) -> int: ...
def ControllabilityMatrix(arg0: LinearSystem) -> numpy.ndarray[numpy.float64[m, n]]: ...
def FirstOrderTaylorApproximation(system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, input_port_index: pydrake.systems.framework.InputPortSelection | pydrake.systems.framework.InputPortIndex = ..., output_port_index: pydrake.systems.framework.OutputPortSelection | pydrake.systems.framework.OutputPortIndex = ...) -> AffineSystem: ...
def IsControllable(sys: LinearSystem, threshold: float | None = ...) -> bool: ...
def IsDetectable(sys: LinearSystem, threshold: float | None = ...) -> bool: ...
def IsObservable(sys: LinearSystem, threshold: float | None = ...) -> bool: ...
def IsStabilizable(sys: LinearSystem, threshold: float | None = ...) -> bool: ...
def Linearize(system: pydrake.systems.framework.System, context: pydrake.systems.framework.Context, input_port_index: pydrake.systems.framework.InputPortSelection | pydrake.systems.framework.InputPortIndex = ..., output_port_index: pydrake.systems.framework.OutputPortSelection | pydrake.systems.framework.OutputPortIndex = ..., equilibrium_check_tolerance: float = ...) -> LinearSystem: ...
def LogVectorOutput(src: pydrake.systems.framework.OutputPort, builder: pydrake.systems.framework.DiagramBuilder, publish_period: float = ...) -> VectorLogSink: ...
def ObservabilityMatrix(arg0: LinearSystem) -> numpy.ndarray[numpy.float64[m, n]]: ...



import numpy as np

from pydrake.common.eigen_geometry import AngleAxis
from pydrake.geometry import (
    Cylinder,
    FrameId,
    GeometryInstance,
    MakePhongIllustrationProperties,
    SceneGraph,
)
from pydrake.math import RigidTransform
from pydrake.multibody.plant import MultibodyPlant
from pydrake.multibody.tree import (
    Frame,
    FrameIndex,
    RigidBody,
)


def AddFrameTriadIllustration(
    *,
    scene_graph: SceneGraph,
    body: RigidBody = None,
    frame: Frame = None,
    frame_index: FrameIndex = None,
    frame_id: FrameId = None,
    plant: MultibodyPlant = None,
    name: str = None,
    length: float = 0.3,
    radius: float = 0.005,
    opacity: float = 0.9,
    X_FT: RigidTransform = None,
):
    """
    Adds illustration geometry representing the given frame using an RGB triad,
    with the x-axis drawn in red, the y-axis in green and the z-axis in blue.
    The given frame can be either a geometry FrameId, a multibody RigidBody,
    a multibody FrameIndex or a multibody Frame.

    Note: exactly one of body=, frame=, frame_index= or frame_id= must be
    provided.

    Note: body frames and frames fixed to bodies are colored differently (body
    frames are brighter).

    Args:
      scene_graph: the SceneGraph where geometry will be added.
      body: when provided, illustrates the frame of the given body.
      frame: when provided, illustrates the frame from a plant.
      frame_index: when provided, illustrates the indexed frame from a plant.
        `plant` must not be None.
      frame_id: when provided, illustrates the given geometry.FrameId
        registered with the given plant and scene_graph.
      plant: MultibodyPlant associated with the given frame_id;
        required if frame_index= or frame_id= is being used. If body= or frame=
        is supplied, they must belong to this plant.
      name: the added geometries will have names "_frames::{name}::x-axis",
        etc. If None, the name is inferred from the indicated frame.
      length: the length of each axis in meters.
      radius: the radius of each axis in meters.
      opacity: the opacity each axis, between 0.0 and 1.0.
      X_FT: optional rigid transform relating frame T (the triad geometry) and
        frame F (the given body=, frame=, or frame_id=  frame); when None, X_FT
        is the identity transform and therefore the triad will depict F.
    Returns:
      The newly-added geometry ids for (x, y, z) respectively.
    """
    if (
        sum(
            [
                body is not None,
                frame is not None,
                frame_index is not None,
                frame_id is not None,
            ]
        )
        != 1
    ):
        raise ValueError(
            "Must provide exactly one of body=, frame=, "
            "frame_index=, or frame_id="
        )
    if X_FT is None:
        X_FT = RigidTransform()
    resolved_plant_arg = "body="
    if frame_index is not None:
        if plant is None:
            raise ValueError(
                "When using frame_index=, the plant cannot be None."
            )
        frame = plant.get_frame(frame_index)
    if frame is not None:
        body = frame.body()
        X_FT = frame.GetFixedPoseInBodyFrame() @ X_FT
        resolved_plant_arg = "frame=" if frame_index is None else "frame_index="
    if body is not None:
        if plant is not None:
            if plant is not body.GetParentPlant():
                raise ValueError(
                    f"Mismatched {resolved_plant_arg} and plant=; remove the "
                    f"plant= arg"
                )
        else:
            plant = body.GetParentPlant()
        frame_id = plant.GetBodyFrameIdOrThrow(body.index())
    if frame is None:
        assert frame_id is not None
        frame = plant.GetBodyFromFrameId(frame_id).body_frame()
    if name is None:
        name = f"{frame.name()}({int(frame.model_instance())})"
    brightness = 1 if frame.is_body_frame() else 0.5

    source_id = plant.get_source_id()
    eye = np.eye(3)
    result = []
    for i, char in enumerate(("x", "y", "z")):
        geom_name = f"_frames::{name}::{char}-axis"
        # p_TG centers the cylinder halfway along the i'th axis.
        p_TG = 0.5 * length * eye[i]
        # R_TG rotates the canonical cylinder (aligned with +z) to align with
        # the i'th axis instead. When i == 2, it spins the cylinder around the
        # z axis, but this is effectively a no-op.
        R_TG = AngleAxis(angle=np.pi / 2, axis=eye[1 - i])
        X_FG = X_FT @ RigidTransform(R_TG, p_TG)
        geom = GeometryInstance(X_FG, Cylinder(radius, length), geom_name)
        phong = MakePhongIllustrationProperties(
            np.append(eye[i] * brightness, [opacity])
        )
        geom.set_illustration_properties(phong)
        geometry_id = scene_graph.RegisterGeometry(source_id, frame_id, geom)
        result.append(geometry_id)
    return tuple(result)
